@@ -2,18 +2,18 @@
 ##'
 ##' @description Monthly potential evapotranspiration
 ##'
-##' @param Tmean rasterStack of monthly mean temperature
+##' @param Tmean SpatRaster of monthly mean temperature
 
-##' @param RA rasterStack of monthly extraterrestrial solar radiation
+##' @param RA SpatRaster of monthly extraterrestrial solar radiation
 ##'
-##' @param TD rasterStack of monthly temperature range
+##' @param TD SpatRaster of monthly temperature range
 ##'
 ##'	@param tempScale integer; scaling factor for the temperature data, see \link{envirem} for 
 ##' 	additional details. 
 ##'
 ##' @details \code{PET = 0.0023 * RA * (Tmean + 17.8) * TD ^ 0.5}
 ##'
-##' @return rasterStack of monthly PET in mm / month
+##' @return SpatRaster of monthly PET in mm / month
 ##'
 ##' @references
 ##' Hargreaves, G. L., Hargreaves, G. H., & Riley, J. P. (1985). Irrigation water requirements 
@@ -35,7 +35,7 @@
 ##' \donttest{
 ##' # Find example rasters
 ##' rasterFiles <- list.files(system.file('extdata', package='envirem'), full.names=TRUE)
-##' env <- stack(rasterFiles)
+##' env <- rast(rasterFiles)
 ##'
 ##' # identify the appropriate layers
 ##' meantemp <- grep('mean', names(env), value=TRUE)
@@ -43,11 +43,11 @@
 ##' maxtemp <- grep('tmax', names(env), value=TRUE)
 ##' mintemp <- grep('tmin', names(env), value=TRUE)
 ##' 
-##' # read them in as rasterStacks
-##' meantemp <- stack(env[[meantemp]])
-##' solar <- stack(env[[solar]])
-##' maxtemp <- stack(env[[maxtemp]])
-##' mintemp <- stack(env[[mintemp]])
+##' # read them in as SpatRasters
+##' meantemp <- env[[meantemp]]
+##' solar <- env[[solar]]
+##' maxtemp <- env[[maxtemp]]
+##' mintemp <- env[[mintemp]]
 ##' tempRange <- abs(maxtemp - mintemp)
 ##' 
 ##' monthlyPET(meantemp, solar, tempRange, tempScale = 10)
@@ -63,13 +63,13 @@
 # as we want annual mean, we'll just use annual mean temp, and mean daily temp range
 monthlyPET <- function(Tmean, RA, TD, tempScale = 1) {
 	
-	if (raster::nlayers(Tmean) != 12) {
+	if (terra::nlyr(Tmean) != 12) {
 		stop('Tmean should have 12 layers.')
 	}
-	if (raster::nlayers(RA) != 12) {
+	if (terra::nlyr(RA) != 12) {
 		stop('RA should have 12 layers.')
 	}
-	if (raster::nlayers(TD) != 12) {
+	if (terra::nlyr(TD) != 12) {
 		stop('TD should have 12 layers.')
 	}
 
@@ -85,9 +85,7 @@ monthlyPET <- function(Tmean, RA, TD, tempScale = 1) {
 	}
 	
 	res <- 0.0023 * (RA * 30) * (Tmean + 17.8) * TD ^ 0.5
-	for (i in 1:raster::nlayers(res)) {
-		raster::values(res[[i]])[which(raster::values(res[[i]]) < 0)] <- 0
-	}
+	res[res < 0] <- 0
 	names(res) <- paste0('PET_', sprintf("%02d", 1:12))
 	return(res)
 }
